'use client'

import React, { useEffect } from 'react'
import { motion, useAnimation } from 'framer-motion'
import { useInView } from 'react-intersection-observer'

interface AchievementProps {
  number: string
  description: string
}

const achievements: AchievementProps[] = [
  { number: "1200+", description: "Happy Clients" },
  { number: "300+", description: "Projects Completed" },
  { number: "50", description: "Awards Won" },
  { number: "25", description: "Countries Served" }
]

const AchievementCard: React.FC<AchievementProps> = ({ number, description }) => {
  const controls = useAnimation()
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1,
  })

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  return (
    <motion.div
      ref={ref}
      className="oas-achievement-card bg-gray-800 rounded-lg p-6 text-center"
      initial="hidden"
      animate={controls}
      variants={{
        hidden: { opacity: 0, y: 20 },
        visible: { opacity: 1, y: 0, transition: { duration: 0.5 } }
      }}
      whileHover={{ scale: 1.05, transition: { duration: 0.2 } }}
    >
      <h3 className="oas-number text-5xl font-bold text-white mb-2">{number}</h3>
      <p className="oas-description text-gray-400">{description}</p>
    </motion.div>
  )
}

const OurAchievementsSection: React.FC = () => {
  const controls = useAnimation()
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1,
  })

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  return (
    <section ref={ref} className="oas-section bg-gray-900 py-16 px-4">
      <div className="oas-container max-w-6xl mx-auto flex flex-col md:flex-row items-center md:items-start">
        <motion.h2 
          className="oas-title text-5xl md:text-6xl font-bold mb-12 md:mb-0 md:mr-12 md:w-1/3"
          initial="hidden"
          animate={controls}
          variants={{
            hidden: { opacity: 0, y: -20 },
            visible: { opacity: 1, y: 0, transition: { duration: 0.5 } }
          }}
        >
          <span className="oas-our block">OUR</span>
          <span className="oas-achievements block">ACHIEVE</span>
          <span className="oas-achievements block">MENTS</span>
        </motion.h2>
        <div className="oas-achievements-grid grid grid-cols-2 md:grid-cols-4 gap-6 md:w-2/3">
          {achievements.map((achievement, index) => (
            <AchievementCard key={index} {...achievement} />
          ))}
        </div>
      </div>
    </section>
  )
}

export default OurAchievementsSection